@@ -65,6 +65,8 @@ class HttpRequest: public HttpMsg
 {
 
 public:
+    typedef HttpMsgPointerT<HttpRequest> Pointer;
+
     MEMPROXY_CLASS(HttpRequest);
     HttpRequest();
     HttpRequest(const HttpRequestMethod& aMethod, protocol_t aProtocol, const char *aUrlpath);
@@ -83,6 +85,8 @@ public:
     /* are responses to this request potentially cachable */
     bool cacheable() const;
 
+    bool conditional() const; ///< has at least one recognized If-* header
+
     /* Now that we care what host contains it is better off being protected. */
     /* HACK: These two methods are only inline to get around Makefile dependancies */
     /*      caused by HttpRequest being used in places it really shouldn't.        */
@@ -161,8 +165,6 @@ public:
 
     int imslen;
 
-    int64_t max_forwards;
-
     IpAddress client_addr;
 
 #if FOLLOW_X_FORWARDED_FOR
@@ -185,6 +187,8 @@ public:
 
     char *peer_domain;		/* Configured peer forceddomain */
 
+    String myportname; // Internal tag name= value from port this requests arrived in.
+
     String tag;			/* Internal tag for this request */
 
     String extacl_user;		/* User name returned by extacl lookup */
@@ -193,6 +197,8 @@ public:
 
     String extacl_log;		/* String to be used for access.log purposes */
 
+    String extacl_message;	/* String to be used for error page purposes */
+
 #if FOLLOW_X_FORWARDED_FOR
     String x_forwarded_for_iterator; /* XXX a list of IP addresses */
 #endif /* FOLLOW_X_FORWARDED_FOR */
