@@ -1,5 +1,5 @@
 /*
- * DEBUG: none          Generate squid.conf.default and cf_parser.h
+ * DEBUG: none          Generate squid.conf.default and cf_parser.cci
  * AUTHOR: Max Okumoto
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -36,7 +36,7 @@
  *		(ie it creates the squid.conf.default file from the cf.data file)
  *
  *		The output files are as follows:
- *		cf_parser.h - this file contains, default_all() which
+ *		cf_parser.cci - this file contains, default_all() which
  *			  initializes variables with the default
  *			  values, parse_line() that parses line from
  *			  squid.conf.default, dump_config that dumps the
@@ -48,7 +48,6 @@
 //#include "squid.h"
 #include "config.h"
 //#include "SquidTime.h"
-#include "cf_gen_defines.h"
 #include "util.h"
 
 #if HAVE_STRING_H
@@ -58,8 +57,10 @@
 #include <ctype.h>
 #endif
 
+#include "cf_gen_defines.cci"
+
 #define MAX_LINE	1024	/* longest configuration line */
-#define _PATH_PARSER		"cf_parser.h"
+#define _PATH_PARSER		"cf_parser.cci"
 #define _PATH_SQUID_CONF	"squid.conf.documented"
 #define _PATH_SQUID_CONF_SHORT	"squid.conf.default"
 #define _PATH_CF_DEPEND		"cf.data.depend"
@@ -550,33 +551,34 @@ gen_default(Entry * head, FILE * fp)
         if (!strcmp(entry->name, "comment"))
             continue;
 
+        if (!strcmp(entry->type, "obsolete"))
+            continue;
+
         if (entry->loc == NULL) {
             fprintf(stderr, "NO LOCATION FOR %s\n", entry->name);
             rc |= 1;
             continue;
         }
 
-        if (entry->default_value == NULL) {
+        if (entry->default_value == NULL && entry->default_if_none == NULL) {
             fprintf(stderr, "NO DEFAULT FOR %s\n", entry->name);
             rc |= 1;
             continue;
         }
 
-        assert(entry->default_value);
-
-        if (entry->ifdef)
-            fprintf(fp, "#if %s\n", entry->ifdef);
-
-        if (strcmp(entry->default_value, "none") == 0) {
+        if (entry->default_value == NULL || strcmp(entry->default_value, "none") == 0) {
             fprintf(fp, "\t/* No default for %s */\n", entry->name);
         } else {
+            if (entry->ifdef)
+                fprintf(fp, "#if %s\n", entry->ifdef);
+
             fprintf(fp, "\tdefault_line(\"%s %s\");\n",
                     entry->name,
                     entry->default_value);
-        }
 
-        if (entry->ifdef)
-            fprintf(fp, "#endif\n");
+            if (entry->ifdef)
+                fprintf(fp, "#endif\n");
+        }
     }
 
     fprintf(fp, "\tcfg_filename = NULL;\n");
@@ -597,7 +599,9 @@ gen_default_if_none(Entry * head, FILE * fp)
 
     for (entry = head; entry != NULL; entry = entry->next) {
         assert(entry->name);
-        assert(entry->loc);
+
+        if (!entry->loc)
+            continue;
 
         if (entry->default_if_none == NULL)
             continue;
@@ -632,7 +636,14 @@ gen_parse_alias(char *name, EntryAlias *alias, Entry *entry, FILE *fp)
 {
     fprintf(fp, "\tif (!strcmp(token, \"%s\")) {\n", name);
 
-    if (strcmp(entry->loc, "none") == 0) {
+    if (strcmp(entry->type,"obsolete") == 0) {
+        fprintf(fp, "\t\tdebugs(0, DBG_CRITICAL, \"ERROR: Directive '%s' is obsolete.\");\n", name);
+        for (Line *line = entry->doc; line != NULL; line = line->next) {
+            // offset line to strip initial whitespace tab byte
+            fprintf(fp, "\t\tdebugs(0, opt_parse_cfg_only?0:1, \"%s : %s\");\n", name, &line->data[1]);
+        }
+        fprintf(fp, "\t\tparse_obsolete(token);\n");
+    } else if (!entry->loc || strcmp(entry->loc, "none") == 0) {
         fprintf(fp,
                 "\t\tparse_%s();\n",
                 entry->type
@@ -662,8 +673,6 @@ gen_parse_entry(Entry *entry, FILE *fp)
 
     EntryAlias *alias = entry->alias;
 
-    assert (entry->loc);
-
     bool more;
 
     do {
@@ -714,9 +723,8 @@ gen_dump(Entry * head, FILE * fp)
            );
 
     for (entry = head; entry != NULL; entry = entry->next) {
-        assert(entry->loc);
 
-        if (strcmp(entry->loc, "none") == 0)
+        if (!entry->loc || strcmp(entry->loc, "none") == 0)
             continue;
 
         if (strcmp(entry->name, "comment") == 0)
@@ -748,9 +756,7 @@ gen_free(Entry * head, FILE * fp)
            );
 
     for (entry = head; entry != NULL; entry = entry->next) {
-        assert(entry->loc);
-
-        if (strcmp(entry->loc, "none") == 0)
+        if (!entry->loc || strcmp(entry->loc, "none") == 0)
             continue;
 
         if (strcmp(entry->name, "comment") == 0)
@@ -811,6 +817,8 @@ gen_conf(Entry * head, FILE * fp, bool verbose_output)
 
         if (!strcmp(entry->name, "comment"))
             (void) 0;
+        else if (!strcmp(entry->name, "obsolete"))
+            (void) 0;
         else if (verbose_output) {
             fprintf(fp, "#  TAG: %s", entry->name);
 
@@ -866,6 +874,8 @@ gen_conf(Entry * head, FILE * fp, bool verbose_output)
 
         if (enabled || verbose_output) {
             for (line = entry->nocomment; line != NULL; line = line->next) {
+                if (!line->data)
+                    continue;
                 if (!enabled && line->data[0] != '#')
                     fprintf(fp, "#%s\n", line->data);
                 else
